<a href="https://darvil82.github.io/PBar/"><img width=50% src="https://user-images.githubusercontent.com/48654552/136713737-aebdd652-061b-428a-b750-2faa29cd60b3.png"><br></a>

<a href="https://github.com/DarviL82/PBar/pulls"> <img src="https://img.shields.io/badge/contributions-welcome-brightgreen?style=flat-square"> </a>
<a href="https://pypi.org/project/PBar2/"> <img src="https://img.shields.io/badge/PyPI-available-blue?style=flat-square"> </a>

---

### PBar is a small work in progress Python library to display customizable progress bars on the terminal easily. Contributions are welcome!


https://user-images.githubusercontent.com/48654552/140072905-f83a1ff4-fba7-481d-925d-727caed6c3e8.mp4


<details>
	<summary><b> More examples </b></summary>

https://user-images.githubusercontent.com/48654552/134776865-c7516cf1-0c66-44da-ae2c-f2cbedd2527c.mp4

Source available [here.](https://github.com/DarviL82/PBar/blob/main/resources/examples/anim.py)


https://user-images.githubusercontent.com/48654552/137568056-aafa1ba1-35c2-4ecd-84f8-99ca0093cab5.mp4

Source available [here.](https://github.com/DarviL82/PBar/blob/main/resources/examples/conds.py)

</details>

<br>

## Wiki
Please visit the different wiki pages available **[here](https://github.com/DarviL82/PBar/wiki)** to see all the features of this package!


## Requirements
Python 3.9+


## Installation
### Pip
PBar is available on the *Python Package Index*:

`pip install pbar2`

You can also install this package through *GitHub* with pip:

`pip install git+https://github.com/DarviL82/PBar`

For uninstalling:

`pip uninstall pbar2`

### AUR
There is also an [*Arch User Repository package*](https://aur.archlinux.org/packages/python-pbar/) made by **MithicSpirit**.


## Additional Credits
| User       | Task          |
|------------|---------------|
| DrMeepster | Type Checking |
